# MLkit

## Install
pip install https://github.com/JamesRitchie/scikit-rvm/archive/master.zip
pip install mlsuite==2.0.6

## Usage
Notice: used pyhton3, not python2

usage: mlsuite.py [-h] [-V] {Fitting,Predict,Auto} ...

The traditional machine learning analysis based on sklearn package:

positional arguments:
  {Fitting,Predict,Auto}
                        machine learning models help.
    Fitting             Fitting and predicting the training and testing set from estimators.
    Predict             predict new data from fittting process model.
    Auto                the auto-processing for all: Fitting and/or Prediction.

optional arguments:
  -h, --help            show this help message and exit
  -V, --version         show program's version number and exit

Example:
1. python mlsuite.py Auto    -i data.traintest.txt -g group.new.txt -p data.predict.txt -o testdt/ -m DT
2. python mlsuite.py Auto    -i data.traintest.txt -g group.new.txt -o testdt/ -m DT
3. python mlsuite.py Fitting -i data.traintest.txt -g group.new.txt -o testdt/ -m DT
4. python mlsuite.py Predict -p data.predict.txt   -g group.new.txt -x modelpath/ -y predictdt/ -m DT.


## Update log
### v2.0.7
    1. repaired same bugs of predict module
### v2.0.6
    1. add RVMrbf and RVMpoly module in MLEstimators.py
### v2.0.2
    1. add SVMpoly module in MLEstimators.py
    2. add calculate MAD function in MLSupervising.py
### v2.0.0
    1. 删除数据预处理、特征筛选、画图等步骤，保留模型构建和模型预测两个步骤。
    2. 13个模型构建，改为并行，缩短分析时间。

### v1.0.0

